# eric7.WebBrowser.Bookmarks.BookmarksImportDialog

Module implementing a dialog for importing bookmarks from other sources.

### Global Attributes

None

### Classes

BookmarksImportDialog | Class implementing a dialog for importing bookmarks from other sources.

### Functions

None

## BookmarksImportDialog

Class implementing a dialog for importing bookmarks from other sources.

### Derived from

QDialog, Ui_BookmarksImportDialog

### Class Attributes

SourcesListIdRole

### Class Methods

None

### Methods

BookmarksImportDialog | Constructor
__enableNextButton | Private slot to set the enabled state of the next button.
getImportedBookmarks | Public method to get the imported bookmarks.
on_cancelButton_clicked | Private slot documentation goes here.
on_filePicker_textChanged | Private slot handling changes of the file to import bookmarks form.
on_nextButton_clicked | Private slot to switch to the next page.
on_sourcesList_itemSelectionChanged | Private slot to handle changes of the selection of the import source.

### Static Methods

None

#### BookmarksImportDialog (Constructor)

BookmarksImportDialog(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### BookmarksImportDialog.__enableNextButton

__enableNextButton()

Private slot to set the enabled state of the next button.

#### BookmarksImportDialog.getImportedBookmarks

getImportedBookmarks()

Public method to get the imported bookmarks.

Return:
  top level bookmark

Return Type:
  BookmarkNode

#### BookmarksImportDialog.on_cancelButton_clicked

on_cancelButton_clicked()

Private slot documentation goes here.

#### BookmarksImportDialog.on_filePicker_textChanged

on_filePicker_textChanged(_txt)

Private slot handling changes of the file to import bookmarks form.

_txt (str)
  text of the line edit (unused)

#### BookmarksImportDialog.on_nextButton_clicked

on_nextButton_clicked()

Private slot to switch to the next page.

#### BookmarksImportDialog.on_sourcesList_itemSelectionChanged

on_sourcesList_itemSelectionChanged()

Private slot to handle changes of the selection of the import source.

Up